@@ -16,15 +16,15 @@ our @EXPORT_OK = qw(number_to_ro ro_to_number);
 
 =head1 NAME
 
-Lingua::RO::Numbers - Converts numeric values into their Romanian string equivalents
+Lingua::RO::Numbers - Convert numeric values into their Romanian string equivalents and viceversa
 
 =head1 VERSION
 
-Version 0.20
+Version 0.21
 
 =cut
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 # Numbers => text
 our %DIGITS;
@@ -50,7 +50,7 @@ our %WORDS;
 @WORDS{qw(unspe doispe treispe paispe cinspe cinsprezece saispe saptespe saptuspe optspe nouaspe)} =
   (11, 12, 13, 14, 15, 15, 16, 17, 17, 18, 19);
 
-# This array contains number greater than 1000 and it's used to convert numbers into text
+# This array contains number greater than 99 and it's used to convert numbers into text
 our @BIGNUMS = (
                 {num => 10**2,  sg => 'suta',        pl => 'sute', fem => 1},
                 {num => 10**3,  sg => 'mie',         pl => 'mii',  fem => 1},
@@ -551,15 +551,17 @@ L<http://search.cpan.org/dist/Lingua-RO-Numbers/>
 
 =back
 
+=head1 REPOSITORY
+
+L<https://github.com/trizen/Lingua-RO-Numbers>
 
 =head1 ACKNOWLEDGEMENTS
 
-    http://ro.wikipedia.org/wiki/Sistem_zecimal#Denumiri_ale_numerelor
-
+L<http://ro.wikipedia.org/wiki/Sistem_zecimal#Denumiri_ale_numerelor>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2013-2014 Daniel "Trizen" Șuteu.
+Copyright 2013-2017 Daniel "Trizen" Șuteu.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
